==> apigateway-0.35.0-sources.jar: software/amazon/awscdk/services/apigateway/RestApi.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Represents a REST API in Amazon API Gateway.
 * 
 * Use `addResource` and `addMethod` to configure the API model.
 * 
 * By default, the API will automatically be deployed and accessible from a
 * public endpoint.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.3 (build 464b8c6)", date = "2019-06-19T15:16:54.655Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.RestApi")
public class RestApi extends software.amazon.awscdk.Resource implements software.amazon.awscdk.services.apigateway.IRestApi {
    protected RestApi(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public RestApi(final software.amazon.awscdk.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.RestApiProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public RestApi(final software.amazon.awscdk.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.apigateway.IRestApi fromRestApiId(final software.amazon.awscdk.Construct scope, final java.lang.String id, final java.lang.String restApiId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.apigateway.RestApi.class, "fromRestApiId", software.amazon.awscdk.services.apigateway.IRestApi.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(restApiId, "restApiId is required") });
    }

    /**
     * Add an ApiKey.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.IApiKey addApiKey(final java.lang.String id) {
        return this.jsiiCall("addApiKey", software.amazon.awscdk.services.apigateway.IApiKey.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Adds a usage plan.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.UsagePlan addUsagePlan(final java.lang.String id, final software.amazon.awscdk.services.apigateway.UsagePlanProps props) {
        return this.jsiiCall("addUsagePlan", software.amazon.awscdk.services.apigateway.UsagePlan.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     * @param method The method (default `*`).
     * @param path The resource path.
     * @param stage The stage (default `*`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi(@javax.annotation.Nullable final java.lang.String method, @javax.annotation.Nullable final java.lang.String path, @javax.annotation.Nullable final java.lang.String stage) {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class, new Object[] { method, path, stage });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     * @param method The method (default `*`).
     * @param path The resource path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi(@javax.annotation.Nullable final java.lang.String method, @javax.annotation.Nullable final java.lang.String path) {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class, new Object[] { method, path });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     * @param method The method (default `*`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi(@javax.annotation.Nullable final java.lang.String method) {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class, new Object[] { method });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi() {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class);
    }

    /**
     * Returns the URL for an HTTP path.
     * 
     * Fails if `deploymentStage` is not set either by `deploy` or explicitly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String urlForPath(@javax.annotation.Nullable final java.lang.String path) {
        return this.jsiiCall("urlForPath", java.lang.String.class, new Object[] { path });
    }

    /**
     * Returns the URL for an HTTP path.
     * 
     * Fails if `deploymentStage` is not set either by `deploy` or explicitly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String urlForPath() {
        return this.jsiiCall("urlForPath", java.lang.String.class);
    }

    /**
     * Performs validation of the REST API.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    protected java.util.List<java.lang.String> validate() {
        return this.jsiiCall("validate", java.util.List.class);
    }

    /**
     * The ID of this API Gateway RestApi.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getRestApiId() {
        return this.jsiiGet("restApiId", java.lang.String.class);
    }

    /**
     * The resource ID of the root resource.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getRestApiRootResourceId() {
        return this.jsiiGet("restApiRootResourceId", java.lang.String.class);
    }

    /**
     * Represents the root resource ("/") of this API. Use it to define the API model:.
     * 
     * api.root.addMethod('ANY', redirectToHomePage); // "ANY /"
     *     api.root.addResource('friends').addMethod('GET', getFriendsHandler); // "GET /friends"
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.IResource getRoot() {
        return this.jsiiGet("root", software.amazon.awscdk.services.apigateway.IResource.class);
    }

    /**
     * The deployed root URL of this REST API.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getUrl() {
        return this.jsiiGet("url", java.lang.String.class);
    }

    /**
     * API Gateway deployment that represents the latest changes of the API. This resource will be automatically updated every time the REST API model changes. This will be undefined if `deploy` is false.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @javax.annotation.Nullable
    public software.amazon.awscdk.services.apigateway.Deployment getLatestDeployment() {
        return this.jsiiGet("latestDeployment", software.amazon.awscdk.services.apigateway.Deployment.class);
    }

    /**
     * API Gateway stage that points to the latest deployment (if defined).
     * 
     * If `deploy` is disabled, you will need to explicitly assign this value in order to
     * set up integrations.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.Stage getDeploymentStage() {
        return this.jsiiGet("deploymentStage", software.amazon.awscdk.services.apigateway.Stage.class);
    }

    /**
     * API Gateway stage that points to the latest deployment (if defined).
     * 
     * If `deploy` is disabled, you will need to explicitly assign this value in order to
     * set up integrations.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void setDeploymentStage(final software.amazon.awscdk.services.apigateway.Stage value) {
        this.jsiiSet("deploymentStage", java.util.Objects.requireNonNull(value, "deploymentStage is required"));
    }
}

==> apigateway-0.36.0-sources.jar: software/amazon/awscdk/services/apigateway/RestApi.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Represents a REST API in Amazon API Gateway.
 * 
 * Use `addResource` and `addMethod` to configure the API model.
 * 
 * By default, the API will automatically be deployed and accessible from a
 * public endpoint.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.12.1 (build 3ce4842)", date = "2019-06-25T14:13:04.413Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.RestApi")
public class RestApi extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.apigateway.IRestApi {
    protected RestApi(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public RestApi(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.RestApiProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public RestApi(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.apigateway.IRestApi fromRestApiId(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final java.lang.String restApiId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.apigateway.RestApi.class, "fromRestApiId", software.amazon.awscdk.services.apigateway.IRestApi.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(restApiId, "restApiId is required") });
    }

    /**
     * Add an ApiKey.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.IApiKey addApiKey(final java.lang.String id) {
        return this.jsiiCall("addApiKey", software.amazon.awscdk.services.apigateway.IApiKey.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Adds a usage plan.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.UsagePlan addUsagePlan(final java.lang.String id, final software.amazon.awscdk.services.apigateway.UsagePlanProps props) {
        return this.jsiiCall("addUsagePlan", software.amazon.awscdk.services.apigateway.UsagePlan.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     * @param method The method (default `*`).
     * @param path The resource path.
     * @param stage The stage (default `*`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi(@javax.annotation.Nullable final java.lang.String method, @javax.annotation.Nullable final java.lang.String path, @javax.annotation.Nullable final java.lang.String stage) {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class, new Object[] { method, path, stage });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     * @param method The method (default `*`).
     * @param path The resource path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi(@javax.annotation.Nullable final java.lang.String method, @javax.annotation.Nullable final java.lang.String path) {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class, new Object[] { method, path });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     * @param method The method (default `*`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi(@javax.annotation.Nullable final java.lang.String method) {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class, new Object[] { method });
    }

    /**
     * Default: "*" returns the execute API ARN for all methods/resources in
     * this API.
     * 
     * EXPERIMENTAL
     * 
     * @return The "execute-api" ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String arnForExecuteApi() {
        return this.jsiiCall("arnForExecuteApi", java.lang.String.class);
    }

    /**
     * Returns the URL for an HTTP path.
     * 
     * Fails if `deploymentStage` is not set either by `deploy` or explicitly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String urlForPath(@javax.annotation.Nullable final java.lang.String path) {
        return this.jsiiCall("urlForPath", java.lang.String.class, new Object[] { path });
    }

    /**
     * Returns the URL for an HTTP path.
     * 
     * Fails if `deploymentStage` is not set either by `deploy` or explicitly.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String urlForPath() {
        return this.jsiiCall("urlForPath", java.lang.String.class);
    }

    /**
     * Performs validation of the REST API.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    protected java.util.List<java.lang.String> validate() {
        return this.jsiiCall("validate", java.util.List.class);
    }

    /**
     * The ID of this API Gateway RestApi.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getRestApiId() {
        return this.jsiiGet("restApiId", java.lang.String.class);
    }

    /**
     * The resource ID of the root resource.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getRestApiRootResourceId() {
        return this.jsiiGet("restApiRootResourceId", java.lang.String.class);
    }

    /**
     * Represents the root resource ("/") of this API. Use it to define the API model:.
     * 
     * api.root.addMethod('ANY', redirectToHomePage); // "ANY /"
     *     api.root.addResource('friends').addMethod('GET', getFriendsHandler); // "GET /friends"
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.IResource getRoot() {
        return this.jsiiGet("root", software.amazon.awscdk.services.apigateway.IResource.class);
    }

    /**
     * The deployed root URL of this REST API.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getUrl() {
        return this.jsiiGet("url", java.lang.String.class);
    }

    /**
     * API Gateway deployment that represents the latest changes of the API. This resource will be automatically updated every time the REST API model changes. This will be undefined if `deploy` is false.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @javax.annotation.Nullable
    public software.amazon.awscdk.services.apigateway.Deployment getLatestDeployment() {
        return this.jsiiGet("latestDeployment", software.amazon.awscdk.services.apigateway.Deployment.class);
    }

    /**
     * API Gateway stage that points to the latest deployment (if defined).
     * 
     * If `deploy` is disabled, you will need to explicitly assign this value in order to
     * set up integrations.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.apigateway.Stage getDeploymentStage() {
        return this.jsiiGet("deploymentStage", software.amazon.awscdk.services.apigateway.Stage.class);
    }

    /**
     * API Gateway stage that points to the latest deployment (if defined).
     * 
     * If `deploy` is disabled, you will need to explicitly assign this value in order to
     * set up integrations.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void setDeploymentStage(final software.amazon.awscdk.services.apigateway.Stage value) {
        this.jsiiSet("deploymentStage", java.util.Objects.requireNonNull(value, "deploymentStage is required"));
    }
}
